==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/pl-PL/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Ten użytkownik może się zalogować',
    'activated_disabled_help_text' => 'Nie możesz edytować statusu aktywacji dla własnego konta.',
    'assets_user'       => 'Aktywa przypisane do :name',
    'bulk_update_warn'	=> 'Zamierzasz edytować właściwości: user_count użytkowników. Należy pamiętać, że nie można zmienić własne atrybuty użytkownika, korzystając z tego formularza i musi przeprowadzić edycję własnych użytkownika indywidualnie.',
    'bulk_update_help'	=> 'Ten formularz umożliwia zbiorczą aktualizację wielu aktywów na raz. Wypełnij tylko te pola, które chcesz zmienić. Puste pola pozostaną niezmienione.',
    'current_assets'    => 'Aktywo obecnie jest przypisane do tego użytkownika',
    'clone'             => 'Kopiuj Użytkownika',
    'contact_user'      => 'Kontakt :name',
    'edit'              => 'Edycja Użytkownika',
    'filetype_info'     => 'Dozwolone typy plików: png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, rar.',
    'history_user'      => 'Historia',
    'info'				=> 'Informacje',
    'restore_user'		=> 'Kliknij tutaj, aby je przywrócić.',
    'last_login'        => 'Ostatnie logowanie',
    'ldap_config_text'  => 'Ustawienia konfiguracji LDAP mogą być znalezione w Administracja -> Ustawienia. Opcjonalnie wybierz lokalizacje, która będzie ustawiona dla zaimportowanych użytkowników.',
    'print_assigned'    => 'Drukuj wszystko przypisane',
    'email_assigned'    => 'Wyślij mailem wszystkie przypisane',
    'user_notified'     => 'Wysłano do użytkowania listę przypisanych zasobów.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Uwzględnij tego użytkownika podczas automatycznego przypisywania kwalifikujących się licencji',
    'auto_assign_help'  => 'Pomiń tego użytkownika w automatycznym przypisaniu licencji',
    'software_user'     => 'Oprogramowanie przypisane do :name',
    'send_email_help'   => 'Musisz podać adres e-mail dla tego użytkownika, aby wysłać mu poświadczenia. Wysłanie danych logowania jest możliwe tylko w czasie tworzenia użytkownika. Hasła są zaszyfrowane i nie można ich odzyskać po zapisaniu.',
    'view_user'         => 'Zobacz Użytkownika :name',
    'usercsv'           => 'plik CSV',
    'two_factor_admin_optin_help' => 'Bieżące ustawienia administracyjne pozwalają na wybiórcze rejestrowanie uwierzytelniania dwuskładnikowego.  ',
    'two_factor_enrolled' => 'Zarejestrowane urządzenie 2FA ',
    'two_factor_active'   => 'Aktywne 2FA ',
    'user_deactivated'  => 'Użytkownik nie może zalogować się',
    'user_activated'  => 'Użytkownik może zalogować się',
    'activation_status_warning' => 'Nie zmieniaj statusu aktywacji',
    'group_memberships_helpblock' => 'Tylko administratorzy mogą edytować członkostwo w grupie.',
    'superadmin_permission_warning' => 'Tylko superadministratorzy mogą udzielić użytkownikowi dostęp do superadmina.',
    'admin_permission_warning' => 'Tylko użytkownicy z uprawnieniami administratora lub większymi mogą udzielić dostępu administratorowi.',
    'remove_group_memberships' => 'Usuń członkostwo grupy',
    'warning_deletion_information' => 'Zamierzasz sprawdzić WSZYSTKIE elementy od :count użytkowników wymienionych poniżej. Super nazwy administratora są zaznaczone na czerwono.',
    'update_user_assets_status' => 'Zaktualizuj wszystkie zasoby dla tych użytkowników do tego statusu',
    'checkin_user_properties' => 'Sprawdź wszystkie właściwości związane z tymi użytkownikami',
    'remote_label'   => 'To jest zdalny użytkownik',
    'remote'   => 'Zdalny',
    'remote_help' => 'Może być przydatne, jeśli chciałbyś filtrować po użytkownikach zdalnych, którzy nigdy lub rzadko są fizycznie w twojej lokalizacji.',
    'not_remote_label' => 'To nie jest zdalny użytkownik',
    'vip_label' => 'Użytkownik VIP',
    'vip_help' => 'To może być pomocne w oznaczaniu ważnych osób w Twojej organizacji, jeśli chcesz obsługiwać je w specjalny sposób.',
    'create_user' => 'Utwórz użytkownika',
    'create_user_page_explanation' => 'To są informacje o koncie, których użyjesz, aby uzyskać dostęp do strony po raz pierwszy.',
    'email_credentials' => 'Dane uwierzytelniające e-mail',
    'email_credentials_text' => 'Wyślij moje poświadczenia na powyższy adres e-mail',
    'next_save_user' => 'Następnie: Zapisz użytkownika',
    'all_assigned_list_generation' => 'Data wygenerowania:',
    'email_user_creds_on_create' => 'Czy wysłać temu użytkownikowi dane logowania mailem?',
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/pl-PL/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Ten użytkownik może się zalogować',
    'activated_disabled_help_text' => 'Nie możesz edytować statusu aktywacji dla własnego konta.',
    'assets_user'       => 'Aktywa przypisane do :name',
    'bulk_update_warn'	=> 'Zamierzasz edytować właściwości: user_count użytkowników. Należy pamiętać, że nie można zmienić własne atrybuty użytkownika, korzystając z tego formularza i musi przeprowadzić edycję własnych użytkownika indywidualnie.',
    'bulk_update_help'	=> 'Ten formularz umożliwia zbiorczą aktualizację wielu aktywów na raz. Wypełnij tylko te pola, które chcesz zmienić. Puste pola pozostaną niezmienione.',
    'current_assets'    => 'Aktywo obecnie jest przypisane do tego użytkownika',
    'clone'             => 'Kopiuj Użytkownika',
    'contact_user'      => 'Kontakt :name',
    'edit'              => 'Edycja Użytkownika',
    'filetype_info'     => 'Dozwolone typy plików: png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, rar.',
    'history_user'      => 'Historia',
    'info'				=> 'Informacje',
    'restore_user'		=> 'Kliknij tutaj, aby je przywrócić.',
    'last_login'        => 'Ostatnie logowanie',
    'ldap_config_text'  => 'Ustawienia konfiguracji LDAP mogą być znalezione w Administracja -> Ustawienia. Opcjonalnie wybierz lokalizacje, która będzie ustawiona dla zaimportowanych użytkowników.',
    'print_assigned'    => 'Drukuj wszystko przypisane',
    'email_assigned'    => 'Wyślij mailem wszystkie przypisane',
    'user_notified'     => 'Wysłano do użytkowania listę przypisanych zasobów.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Uwzględnij tego użytkownika podczas automatycznego przypisywania kwalifikujących się licencji',
    'auto_assign_help'  => 'Pomiń tego użytkownika w automatycznym przypisaniu licencji',
    'software_user'     => 'Oprogramowanie przypisane do :name',
    'view_user'         => 'Zobacz Użytkownika :name',
    'usercsv'           => 'plik CSV',
    'two_factor_admin_optin_help' => 'Bieżące ustawienia administracyjne pozwalają na wybiórcze rejestrowanie uwierzytelniania dwuskładnikowego.  ',
    'two_factor_enrolled' => 'Zarejestrowane urządzenie 2FA ',
    'two_factor_active'   => 'Aktywne 2FA ',
    'user_deactivated'  => 'Użytkownik nie może zalogować się',
    'user_activated'  => 'Użytkownik może zalogować się',
    'activation_status_warning' => 'Nie zmieniaj statusu aktywacji',
    'group_memberships_helpblock' => 'Tylko administratorzy mogą edytować członkostwo w grupie.',
    'superadmin_permission_warning' => 'Tylko superadministratorzy mogą udzielić użytkownikowi dostęp do superadmina.',
    'admin_permission_warning' => 'Tylko użytkownicy z uprawnieniami administratora lub większymi mogą udzielić dostępu administratorowi.',
    'remove_group_memberships' => 'Usuń członkostwo grupy',
    'warning_deletion_information' => 'Zamierzasz sprawdzić WSZYSTKIE elementy od :count użytkowników wymienionych poniżej. Super nazwy administratora są zaznaczone na czerwono.',
    'update_user_assets_status' => 'Zaktualizuj wszystkie zasoby dla tych użytkowników do tego statusu',
    'checkin_user_properties' => 'Sprawdź wszystkie właściwości związane z tymi użytkownikami',
    'remote_label'   => 'To jest zdalny użytkownik',
    'remote'   => 'Zdalny',
    'remote_help' => 'Może być przydatne, jeśli chciałbyś filtrować po użytkownikach zdalnych, którzy nigdy lub rzadko są fizycznie w twojej lokalizacji.',
    'not_remote_label' => 'To nie jest zdalny użytkownik',
    'vip_label' => 'Użytkownik VIP',
    'vip_help' => 'To może być pomocne w oznaczaniu ważnych osób w Twojej organizacji, jeśli chcesz obsługiwać je w specjalny sposób.',
    'create_user' => 'Utwórz użytkownika',
    'create_user_page_explanation' => 'To są informacje o koncie, których użyjesz, aby uzyskać dostęp do strony po raz pierwszy.',
    'email_credentials' => 'Dane uwierzytelniające e-mail',
    'email_credentials_text' => 'Wyślij moje poświadczenia na powyższy adres e-mail',
    'next_save_user' => 'Następnie: Zapisz użytkownika',
    'all_assigned_list_generation' => 'Data wygenerowania:',
    'email_user_creds_on_create' => 'Czy wysłać temu użytkownikowi dane logowania mailem?',
    'department_manager' => 'Menedżer działu',
];
